pub enum RetryOptions<'a> {
Failed(&'a BackOffJobOptions),
WithRepeat(&'a Repeat),
}Expand description
Specifies how a job should be retried after a failure or completion.
Passed to crate::Queue::retry_job.
Variants
Failed(&'a BackOffJobOptions)
Retry a failed job using the given backoff options.
WithRepeat(&'a Repeat)
Re-enqueue a job according to a Repeat policy.